@@ -1,28 +1,28 @@
 r"""
 Define your classes and create the instances that you need to expose
 """
+import logging
 from .reactions import register_reactions
 from .proxymanager import ParaviewProxyManager
 from paraview import simple
 
+logger = logging.getLogger(__name__)
+logger.setLevel(logging.INFO)
+
 # ---------------------------------------------------------
 # Methods
 # ---------------------------------------------------------
 
 
-def initialize(server):
-    args, _ = server.cli.parse_known_args()
-    #
+def initialize(server, plugins=None):
     pxm = ParaviewProxyManager()
     pxm.set_server(server)
 
-    plugins = args.plugins.split(",") if args.plugins else []
     if plugins:
-        print("\nLoading ParaView plugins:")
+        logger.info("\nLoading ParaView plugins:")
         for plugin in plugins:
-            print(f"  - {plugin}")
+            logger.info(f"  - {plugin}")
             simple.LoadDistributedPlugin(plugin)
-        print()
 
     # Bind methods to controller + trigger name
     register_reactions(server)
