@@ -1,7 +1,4 @@
-try:
-    from paraview import servermanager
-except:
-    pass
+from paraview import servermanager
 
 
 def unwrap(obj):
@@ -15,7 +12,7 @@ def unwrap(obj):
 def id_to_proxy(poxy_id):
     try:
         poxy_id = int(poxy_id)
-    except:
+    except Exception:
         return None
     if poxy_id <= 0:
         return None
