@@ -6,7 +6,7 @@ def initialize(server):
 
     @state.change("active_controls")
     def update_active_panel(active_controls, **kwargs):
-        state.drawer_visibility = active_controls is not None
+        state.main_drawer = active_controls is not None
 
     @ctrl.add("on_active_proxy_change")
     def update_active_proxies(**kwargs):
